<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu_HU">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About iTALC</source>
        <translation type="unfinished">Az iTALC névjegye</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished">Névjegy</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://italc.sourceforge.net&quot;&gt;http://italc.sourceforge.net&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;http://italc.sourceforge.net&quot;&gt;http://italc.sourceforge.net&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation type="unfinished">Szerzők</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Fordítás</translation>
    </message>
    <message>
        <source>Current language not translated yet (or native English).

If you&apos;re interested in translating iTALC into your local or another language or want to improve an existing translation, please contact an iTALC developer!</source>
        <translation type="unfinished">A magyar fordítást készítették a Novell PSH Kft. munkatársai:
Maxi Attila, Kovács Lajos és Óvári Ákos

Amennyiben hibát talál a magyar fordításban, kérem mielőbb jelezze a Novell PSH Kft. munkatársai felé: huedudl@npsh.hu e-mail címen.

Ha szeretné lefordítani másik nyelvre is, kérem jelezze az iTALC fejlesztőcsapatának.</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <source>iTALC - Intelligent Teaching And Learning with Computers

Copyright © 2004-2013 Tobias Doerffel / iTALC Solutions</source>
        <translation type="unfinished">iTALC - Intelligent Teaching And Learning with Computer

Copyright © 2004-2011 Tobias Doerffel / iTALC Solutions
 {2004-2013 ?}</translation>
    </message>
</context>
<context>
    <name>AccessDialogSlave</name>
    <message>
        <source>Never for this session</source>
        <translation type="unfinished">Ebben a munkamenetben soha</translation>
    </message>
    <message>
        <source>Always for this session</source>
        <translation type="unfinished">Ebben a munkamenetben mindig</translation>
    </message>
    <message>
        <source>Confirm desktop access</source>
        <translation type="unfinished">Hozzáférés megerősítése a munkaasztalhoz</translation>
    </message>
    <message>
        <source>The user %1 at host %2 wants to access your desktop. Do you want to grant access?</source>
        <translation type="unfinished">%1 felhasználó a(z) %2 gépről hozzáférést kezdeményezett az Ön munkaasztalához. Engedélyezi?</translation>
    </message>
</context>
<context>
    <name>ClassroomManager</name>
    <message>
        <source>Classroom-Manager</source>
        <translation>Osztályterem-Kezelés</translation>
    </message>
    <message>
        <source>Use this workspace to manage your computers and classrooms in an easy way.</source>
        <translation>Ezen a munkaasztalon kezelheti a számítógépeket és az osztálytermeket</translation>
    </message>
    <message>
        <source>This is where computers and classrooms are managed. You can add computers or classrooms by clicking right in this list.</source>
        <translation>Itt tudja kezelni a számítógépeit és az osztálytermeit. Számítógép vagy osztályterem hozzáadásához kattintson az egér jobb gombjával a listára.</translation>
    </message>
    <message>
        <source>Classrooms/computers</source>
        <translation>Osztálytermek/Számítógépek</translation>
    </message>
    <message>
        <source>IP-address</source>
        <translation>IP-Cím</translation>
    </message>
    <message>
        <source>Usernames</source>
        <translation>Felhasználók</translation>
    </message>
    <message>
        <source>Show usernames</source>
        <translation type="unfinished">Felhasználók megjelenítése</translation>
    </message>
    <message>
        <source>Use the context-menu (right mouse-button) to add/remove computers and/or classrooms.</source>
        <translation type="unfinished">A lenyíló menü segítségével (egér jobb gomb megnyomásával) hozzáadhatja, törölheti a számítógépeket vagy osztálytermeket.</translation>
    </message>
    <message>
        <source>Export to text-file</source>
        <translation type="unfinished">Exportálás fájlba</translation>
    </message>
    <message>
        <source>Use this button for exporting this list of computers and usernames into a text-file. You can use this file later for collecting files after an exam has finished. This is sometimes necessary, because some users might have finished and logged out earlier and so you cannot collect their files at the end of the exam.</source>
        <translation type="unfinished">A gomb segítségével exportálhatja a számítógépeket és a felhasználókat a szöveges állományba. A vizsga befejeztével egyszerűen begyűjtheti ezeket a fájlokat. Néhány alkalommal szükséges lehet, mert a vizsgával már korábban végzett és kijelentkezett felhasználók már nem érhetőek el a rendszerben.</translation>
    </message>
    <message>
        <source>Hide teacher computers</source>
        <translation>Tanári számítógépek elrejtése</translation>
    </message>
    <message>
        <source>Show/hide</source>
        <translation>Megtekint/Elrejt</translation>
    </message>
    <message>
        <source>Edit settings</source>
        <translation>Beállítások szerkesztése</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Show all computers in classroom</source>
        <translation>Összes számítógép megtekintése az osztályteremben</translation>
    </message>
    <message>
        <source>Hide all computers in classroom</source>
        <translation>Összes számítógép elrejtése az osztályteremben</translation>
    </message>
    <message>
        <source>Edit name</source>
        <translation>Név szerkesztése</translation>
    </message>
    <message>
        <source>Remove classroom</source>
        <translation>Osztályterem törlése</translation>
    </message>
    <message>
        <source>Add computer</source>
        <translation>Számítógép hozzáadása</translation>
    </message>
    <message>
        <source>Add classroom</source>
        <translation>Osztályterem hozzáadása</translation>
    </message>
    <message>
        <source>No configuration-file found</source>
        <translation>Nem található a konfigurációs fájl</translation>
    </message>
    <message>
        <source>Could not open configuration file %1.
You will have to add at least one classroom and computers using the classroom-manager which you&apos;ll find inside the program in the sidebar on the left side.</source>
        <translatorcomment>Legalább egy számítógépterem csoportot definiálnunk kell ahhoz, hogy a számítógép(ek)et megfelelően tudjuk kezelni a bal oldalsávon.</translatorcomment>
        <translation type="unfinished">Nem nyitható meg a %1 konfigurációs fájl.
Legalább egy számítógépterem csoportot definiálnunk kell ahhoz, hogy a számítógép(ek)et megfelelően tudjuk kezelni a bal oldalsávon.</translation>
    </message>
    <message>
        <source>Error in configuration-file</source>
        <translation>Hiba a konfigurációs fájlban</translation>
    </message>
    <message>
        <source>Error while parsing configuration-file %1.
Please edit it. Otherwise you should delete this file and have to add all classrooms and computers again.</source>
        <translation type="unfinished">Hiba történt a %1 konfigurációs fájl feldogozása közben.
Kérem módosítsa, máskülönben törlésre kerülhet a fájl és újból létre kell hozni az összes osztályterme(ke)t és számítógépe(ke)t.</translation>
    </message>
    <message>
        <source>Error while parsing configuration-file %1.
Please edit it. Otherwise you should delete this file.</source>
        <translation type="unfinished">Hiba történt a %1 konfigurációs fájl feldogozása közben.
Kérem módosítsa, máskülönben törlésre kerülhet a fájl.</translation>
    </message>
    <message>
        <source>Select output-file</source>
        <translation>Kimeneti fájl kiválasztása</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>Szöveges fájlok (*.txt)</translation>
    </message>
    <message>
        <source>Actions for selected</source>
        <translation type="unfinished">Kiválasztottak műveletei</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Műveletek</translation>
    </message>
    <message>
        <source>Actions for %1</source>
        <translation type="unfinished">%1 terem műveletei</translation>
    </message>
    <message>
        <source>New name for classroom</source>
        <translation>Új név hozzáadása az osztályteremhez</translation>
    </message>
    <message>
        <source>Please enter a new name for classroom &quot;%1&quot;.</source>
        <translation>Kérem írja be az új osztály terem nevét &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Are you sure want to remove classroom &quot;%1&quot;?
All computers in it will be removed as well!</source>
        <translation type="unfinished">Biztos benne, hogy törli a &quot;%1&quot; osztálytermet?
Az összes számítógép törlésre kerül!</translation>
    </message>
    <message>
        <source>Missing classroom</source>
        <translation>Hiányzó osztályterem</translation>
    </message>
    <message>
        <source>Before adding computers you have to create at least one classroom.
Do you want to create a new classrom now?</source>
        <translation type="unfinished">Új számítógép hozzáadása előtt, hozzon létre egy osztálytermet.
Szeretne létrehozni új osztálytermet?</translation>
    </message>
    <message>
        <source>New classroom</source>
        <translation>Új osztályterem</translation>
    </message>
    <message>
        <source>Please enter the name of the classroom you want to create.</source>
        <translation type="unfinished">Kérem írja be az osztályterem nevét, amit létre szeretne hozni.</translation>
    </message>
</context>
<context>
    <name>Client</name>
    <message>
        <source>Unknown state</source>
        <translation>Ismeretlen állapot</translation>
    </message>
    <message>
        <source>No user logged in</source>
        <translation>Nincsen felhasználó bejelentkezve</translation>
    </message>
    <message>
        <source>Host unreachable</source>
        <translation>A számítógép nem érhető el</translation>
    </message>
    <message>
        <source>Demo running</source>
        <translation type="unfinished">Aktuális bemutatói futás</translation>
    </message>
    <message>
        <source>Desktop locked</source>
        <translation type="unfinished">Blokkolt asztal</translation>
    </message>
</context>
<context>
    <name>ClientAction</name>
    <message>
        <source>Are you sure want logout all users on all visible computers ?</source>
        <translatorcomment>Biztosan ki szeretné jelentkeztetni az összes felhasználót a kijelölt számítógépekről?</translatorcomment>
        <translation type="unfinished">Biztosan szeretné,hogy az összes felhasználó kijelentkezzen a számítógépekről?</translation>
    </message>
    <message>
        <source>Are you sure want logout all users on all selected computers ?</source>
        <translatorcomment>Biztosan ki szeretné jelentkeztetni az összes felhasználót a kijelölt számítógépekről?</translatorcomment>
        <translation type="unfinished">Biztosan szeretné,hogy az összes felhasználó kijelentkezzen a kijelölt számítógépekről?</translation>
    </message>
    <message>
        <source>Logout user</source>
        <translation type="unfinished">Felhasználói kijelentkezés</translation>
    </message>
    <message>
        <source>Are you sure want to reboot all visible computers?</source>
        <translation type="unfinished">Biztos benne, hogy újra szeretné indítani az összes számítógépet?</translation>
    </message>
    <message>
        <source>Are you sure want to reboot all selected computers?</source>
        <translation type="unfinished">Biztos benne, hogy újra szeretné indítani az összes kijelölt számítógépet?</translation>
    </message>
    <message>
        <source>Reboot computers</source>
        <translation type="unfinished">Számítógépek újraindítása</translation>
    </message>
    <message>
        <source>Are you sure want to power down all visible computers?</source>
        <translation type="unfinished">Biztos benne, hogy ki szeretné kapcsolni az összes számítógépet?</translation>
    </message>
    <message>
        <source>Are you sure want to power down all selected computers?</source>
        <translation type="unfinished">Biztos benne, hogy ki szeretné kapcsolni az összes kijelölt számítógépet?</translation>
    </message>
</context>
<context>
    <name>ClientSettingsDialog</name>
    <message>
        <source>Invalid MAC-address</source>
        <translation type="unfinished">Érvénytelen MAC azonosító</translation>
    </message>
    <message>
        <source>You specified an invalid MAC-address. Either leave the field blank or enter a valid MAC-address (use &quot;:&quot; as separator!).</source>
        <translation type="unfinished">Érvénytelen MAC azonosítót adott meg. Hagyja üresen a mezőt vagy adjon meg egy érvényes MAC azonosítót (használjon &quot;:&quot; az elválasztáshoz!).</translation>
    </message>
    <message>
        <source>Client settings</source>
        <translation type="unfinished">Kliens beállítások</translation>
    </message>
    <message>
        <source>IP/hostname</source>
        <translation type="unfinished">IP cím vagy gépnév</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;enter an IP-address or hostname under which iTALC can reach the client (use &apos;:&apos; for specifying an optional port-number)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;adja meg az IP címet vagy gépnevet, amivel iTALC elérheti a kliens gépeket (használjon &quot;:&quot; - megadhatározhatja a kívánt port számát)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Név</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Optional nickname of the host which is displayed in iTALC.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Adjon meg egy becenevet a géphez, amit szeretne hogy az iTALC-ban megjelenjen.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>MAC address</source>
        <translation type="unfinished">MAC azonosító</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Hardware/MAC-address of client - only used for powering on client&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Hardver/MAC azonosítója a kliensnek - csak a számítógép bekapcsolásához használatos&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Classroom</source>
        <translation type="unfinished">Osztályterem</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Típus</translation>
    </message>
    <message>
        <source>Student computer</source>
        <translation type="unfinished">Diák számítógép</translation>
    </message>
    <message>
        <source>Teacher computer</source>
        <translation type="unfinished">Tanári számítógép</translation>
    </message>
    <message>
        <source>Other/undefined computer</source>
        <translation type="unfinished">Hozzá nem rendelt számítógép</translation>
    </message>
    <message>
        <source>Missing IP address/hostname</source>
        <translation type="unfinished">Hiányzó IP cím/gépnév</translation>
    </message>
    <message>
        <source>You didn&apos;t specify an IP address or hostname for the computer!</source>
        <translation type="unfinished">Még nem adta hozzá az IP címet vagy a gépnevet a számítógéphez!</translation>
    </message>
</context>
<context>
    <name>Config</name>
    <message>
        <source>Interval between updates</source>
        <translation type="unfinished">Képfrissítés gyakorisága</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can set the interval between updates of clients. Higher values result in lower network-traffic and lower CPU-usage on this computer.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can set the interval between updates of clients. Higher values result in lower network-traffic and lower CPU-usage on this computer.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source> seconds</source>
        <translation type="unfinished"> másodperc</translation>
    </message>
    <message>
        <source>User interface</source>
        <translation type="unfinished">Felhasználói felület</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Do not show balloon-tooltips for toolbar-buttons&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Check this option if you&apos;re annoyed by the balloon-tooltips appearing when moving mouse-cursor over toolbar-buttons.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No balloon-tooltips</source>
        <translation type="unfinished">Felugró üzenetek tiltása</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Do not show texts on toolbar-buttons&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No texts on toolbar-buttons</source>
        <translation type="unfinished">Felirat nélküli eszköztár</translation>
    </message>
    <message>
        <source>Your role (needs according keys!)</source>
        <translation type="unfinished">Szerepkörök (hozzáférési kulcsok szerint)</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can select your role. Only change this if you know what you&apos;re doing. Otherwise you won&apos;t be able to access any clients until you restore your old role.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Itt választhatja ki a szerepköröket. Csak akkor változtassa meg, ha biztosan tudja, hogy mit csinál. Az is előfordulhat máskülönben, hogy nem fog tudni hozzáférni a kliens gépekhez, csak akkor ha visszaállítja az eredeti beállításokat.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Teacher</source>
        <translation type="unfinished">Tanár</translation>
    </message>
    <message>
        <source>Administrator</source>
        <translation type="unfinished">Adminisztrátor</translation>
    </message>
    <message>
        <source>Supporter</source>
        <translation type="unfinished">Támogató</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">Más</translation>
    </message>
    <message>
        <source>Settings for multi-logon</source>
        <translation type="unfinished">Tartomány beállításai</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation type="unfinished">Domain</translation>
    </message>
    <message>
        <source>Double-click action for client-window</source>
        <translation type="unfinished">Dupla kattintás a kliens ablakhoz</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can set what should happen if you double-click a client-window.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation type="unfinished">Távoli hozzáférés</translation>
    </message>
    <message>
        <source>View live in fullscreen</source>
        <translation type="unfinished">Teljes képernyős élő nézet</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-style:italic;&quot;&gt;Please note, that some changes won&apos;t take effect until you restart iTALC.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-style:italic;&quot;&gt;Felhívjuk a figyelmét arra, hogy az egyes változások életbelépéshez újra kell indítani az iTALC szolgáltatást.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ar - العربية</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cs - Česky</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>de - Deutsch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>el - Ελληνικά</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>es - Español</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fi - Suomi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fr - Français</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>he - עִבְרִית</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hu - Magyar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>it - Italiano</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>nl - Nederlands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>nn - Norsk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pl - Polski</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pt_br - Brasileiro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pt_pt - Português</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ru - Русский</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sk - Slovenský</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sl - Slovenčina</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sv - Svenska</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>tr - Türkçe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>uk - Українська</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zh_cn - 简体字</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zh_tw - 簡體字</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigWidget</name>
    <message>
        <source>Your iTALC-configuration</source>
        <translation type="unfinished">iTALC konfiguráció</translation>
    </message>
    <message>
        <source>In this workspace you can customize iTALC to fit your needs.</source>
        <translation type="unfinished">Ezen a munkaterületen szabhatja testre az iTALC-t az Ön igényeinek megfelelően.</translation>
    </message>
</context>
<context>
    <name>DecoratedMessageBox</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>DemoClient</name>
    <message>
        <source>iTALC Demo</source>
        <translation type="unfinished">iTALC Bemutató</translation>
    </message>
</context>
<context>
    <name>ItalcCoreServer</name>
    <message>
        <source>Authentication error</source>
        <translation type="unfinished">Bejelentkezési probléma</translation>
    </message>
    <message>
        <source>Somebody (IP: %1) tried to access this computer but could not authenticate itself successfully!</source>
        <translatorcomment>Valaki (IP: %1) megpróbálta elérni ezt a számítógéphez, de nem tudta hitelesíteni magát!</translatorcomment>
        <translation type="unfinished">Valaki (IP: %1) megpróbált hozzáférni ehhez a számítógéphez, de nem tudta megfelelően hitelesíteni magát!</translation>
    </message>
</context>
<context>
    <name>ItalcVncConnection</name>
    <message>
        <source>VNC authentication failed because of too many authentication tries.</source>
        <translation type="unfinished">Túl sok próbálkozás miatt a VNC bejelentkezések száma hibára futott.</translation>
    </message>
    <message>
        <source>VNC authentication failed.</source>
        <translation type="unfinished">VNC bejelentkezési probléma.</translation>
    </message>
    <message>
        <source>VNC server closed connection.</source>
        <translation type="unfinished">VNC szerver lezárta a kapcsolatot.</translation>
    </message>
</context>
<context>
    <name>KeyFileAssistant</name>
    <message>
        <source>iTALC Access Key Assistant</source>
        <translation type="unfinished">iTALC hozzáférési kulcs Varázsló</translation>
    </message>
    <message>
        <source>Create/import iTALC access keys</source>
        <translation type="unfinished">Hozzáférési kulcs Készítése/Importálása</translation>
    </message>
    <message>
        <source>This assistant will help you to create or import iTALC access keys.</source>
        <translation type="unfinished">A Varázsló segítségével létrehozhatunk vagy importálhatunk hozzáférési kulcsokat.</translation>
    </message>
    <message>
        <source>How does it work?</source>
        <translation type="unfinished">Hogyan működik ?</translation>
    </message>
    <message>
        <source>iTALC access keys consist of two parts belonging together, a private and a public key part.

Using the private key part, users on the master computer will be able to access client computers. It is important that only authorized users have read access to the private key file.

The public key part is used on the client computers to verify that any incoming connection request is authorized.</source>
        <translation type="unfinished">A hozzáférési azonosítás egy kulcspár segítségével valósul meg, ami a privát kulcs és publikus kulcsból áll.

A privát kulcs a master (tanári) számítógépen azonosítja a kliens gépeket. Nagyon fontos, hogy csak azonosított felhasználóknak legyen joga a privát kulcs olvasásához!

A publikus kulcs a kliens (diák) számítógépein azonosítja a bejövő kérések hitelességét.</translation>
    </message>
    <message>
        <source>Assistant mode</source>
        <translation type="unfinished">Varázsló mód</translation>
    </message>
    <message>
        <source>Please choose whether to create new access keys or import a public key on a client.</source>
        <translation type="unfinished">Kérjük válassza ki, hogy létrehozni vagy importálni szeretne egy új hozzáférési kulcsot a kliens számára.</translation>
    </message>
    <message>
        <source>Create new access keys (master computer)</source>
        <translation type="unfinished">Új hozzáférési kulcsok készítése (tanári számítógép)</translation>
    </message>
    <message>
        <source>assistantModeButtonGroup</source>
        <translation type="unfinished">assistantModeButtonGroup</translation>
    </message>
    <message>
        <source>Import public key (client computer)</source>
        <translation type="unfinished">Publikus kulcs importálás (kliens számítógép)</translation>
    </message>
    <message>
        <source>Select user role</source>
        <translation type="unfinished">Szerepkör kiválasztása</translation>
    </message>
    <message>
        <source>Please select a user role for which to create or import the access keys:</source>
        <translation type="unfinished">Kérjük válassza ki azt a felhasználót, aki számára létrehonzi vagy importálni szeretné a hozzáférési kulcsot:</translation>
    </message>
    <message>
        <source>Teacher</source>
        <translation type="unfinished">Tanár</translation>
    </message>
    <message>
        <source>Administrator</source>
        <translation type="unfinished">Adminisztrátor</translation>
    </message>
    <message>
        <source>Support team member</source>
        <translation type="unfinished">Támogatók</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">Más</translation>
    </message>
    <message>
        <source>User roles allow using multiple access keys in parallel. For example there can be different teacher access keys for each classroom while the support access keys are the same for the whole school.</source>
        <translation type="unfinished">A felhasználói szerepkörökhöz rendelt hozzáférési kulcsok lehetővé teszik a párhuzamos hozzáférést. Például: Minden osztályteremhez különböző tanári kulcsok tartozhatnak, de az iskolára nézve elegendő egy támogatói (support) kulcs készítése.</translation>
    </message>
    <message>
        <source>Directories</source>
        <translation type="unfinished">Könyvtárak</translation>
    </message>
    <message>
        <source>Export public key part (master computer)</source>
        <translation type="unfinished">Publikus kulcspár exportálása (tanári számítógép)</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Use custom destination directory for access keys</source>
        <translation type="unfinished">A hozzáférési kulcsok mentése egyéni könyvtárba</translation>
    </message>
    <message>
        <source>Please specify the location of the public access key to be imported.</source>
        <translation type="unfinished">Kérem határozza meg a publikus kulcs importálásához az elérési útvonalat.</translation>
    </message>
    <message>
        <source>Summary</source>
        <translation type="unfinished">Összefoglalás</translation>
    </message>
    <message>
        <source>The following actions will be taken:</source>
        <translation type="unfinished">A következő műveletekre kerül sor:</translation>
    </message>
    <message>
        <source>• Create new access keys</source>
        <translation type="unfinished">• Új hozzáférési kulcs elkészítése</translation>
    </message>
    <message>
        <source>• Import public access key from</source>
        <translation type="unfinished">• Publikus kulcs importálás</translation>
    </message>
    <message>
        <source>&lt;unknown&gt;</source>
        <translation type="unfinished">&lt;unknown&gt;</translation>
    </message>
    <message>
        <source>• Write access key(s) to</source>
        <translation>• Hozzáférési kulcs(ok) másolása ide:</translation>
    </message>
    <message>
        <source>• Export public key to</source>
        <translation>• Publikus kulcs exportálás ide:</translation>
    </message>
    <message>
        <source>• Configure for user role</source>
        <translation type="unfinished">• Felhasználói szerepkör beállítása:</translation>
    </message>
    <message>
        <source>Select directory in which to export the public key</source>
        <translation type="unfinished">Válassza ki azt a könyvtárat, ahonnan exportálni szeretné a publikus kulcsot</translation>
    </message>
    <message>
        <source>Key files (*.key.txt)</source>
        <translation type="unfinished">Kulcs fájlok (*.key.txt)</translation>
    </message>
    <message>
        <source>Invalid public key</source>
        <translation type="unfinished">Érvénytelen publikus kulcs</translation>
    </message>
    <message>
        <source>The selected file does not contain a valid public iTALC access key!</source>
        <translation type="unfinished">A kiválasztott fájl nem tartalmaz érvényes hozzáférési publikus kulcs adatokat az iTALC-hoz!</translation>
    </message>
    <message>
        <source>Select destination directory</source>
        <translation type="unfinished">Cél könyvtár megadása</translation>
    </message>
    <message>
        <source>Access key creation</source>
        <translation type="unfinished">Hozzáférési kulcs készítése</translation>
    </message>
    <message>
        <source>Could not remove previously existing file %1.</source>
        <translation type="unfinished">Nem sikerült eltávolítani,a létező fájlt: %1.</translation>
    </message>
    <message>
        <source>Failed exporting public access key from %1 to %2.</source>
        <translation type="unfinished">Sikertelen volt a publikus kulcs exportálás a %1-ról a %2-re.</translation>
    </message>
    <message>
        <source>Access keys were created and written successfully to %1 and %2.</source>
        <translation type="unfinished">Sikeresen létrehozta a hozzáférési kulcspárt. A mentése helye: %1 és %2 könvytárban.</translation>
    </message>
    <message>
        <source>An error occured while creating the access keys. You probably are not permitted to write to the selected directories.</source>
        <translation type="unfinished">A hozzáférési kulcs készítése közben probléma történt. Valószínűleg nincsen írási joga a kiválasztott könyvtárba.</translation>
    </message>
    <message>
        <source>Public key import</source>
        <translation type="unfinished">Publikus kulcs importálása</translation>
    </message>
    <message>
        <source>An error occured while importing the public access key. You probably are not permitted to read the source key or to write the destination file.</source>
        <translation type="unfinished">A publikus kulcs importálás közben hiba lépett fel. Önnek valószínűleg nincsen olvasási joga a forrás fájlból, vagy írási joga a cél fájlba.</translation>
    </message>
    <message>
        <source>The public key was successfully imported to %1.</source>
        <translation type="unfinished">A publikus kulcs importálása sikeresen végrehajtódott a %1-ba.</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>screen lock</source>
        <translation type="unfinished">Képernyő blokkolása</translation>
    </message>
</context>
<context>
    <name>LogonGroupEditor</name>
    <message>
        <source>Logon group editor</source>
        <translation type="unfinished">Bejelentkezési csoport szerkesztő</translation>
    </message>
    <message>
        <source>Please add the groups whose members should be allowed to access computers in your iTALC network.</source>
        <translation type="unfinished">Kérjük a csoportokhoz rendelje hozzá azokat, akiknek engedélyezi az iTALC hálózati a hozzáférést.</translation>
    </message>
    <message>
        <source>All groups</source>
        <translation type="unfinished">Minden csoport</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Groups with iTALC privileges</source>
        <translation type="unfinished">Csoportok iTALC jogosultságokkal</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>Actions</source>
        <translation type="unfinished">Műveletek</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>General</source>
        <translation type="unfinished">Általános</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished">Kilépés</translation>
    </message>
    <message>
        <source>iTALC Management Console</source>
        <translation type="unfinished">iTALC Kezelő Konzol</translation>
    </message>
    <message>
        <source>iTALC Server</source>
        <translation type="unfinished">iTALC-Szerver</translation>
    </message>
    <message>
        <source>Paths</source>
        <translation type="unfinished">Útvonalak</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="unfinished">Hitelesítés</translation>
    </message>
    <message>
        <source>iTALC Service</source>
        <translation type="unfinished">iTALC-Szolgáltatás</translation>
    </message>
    <message>
        <source>Hide tray icon</source>
        <translatorcomment>Tálca icon elrejtése</translatorcomment>
        <translation type="unfinished">Icon elrejtése a tálcáról</translation>
    </message>
    <message>
        <source>Autostart</source>
        <translation type="unfinished">Automatikus indítása</translation>
    </message>
    <message>
        <source>Additional arguments</source>
        <translation type="unfinished">További paraméterek</translation>
    </message>
    <message>
        <source>Start service</source>
        <translation type="unfinished">Szolgáltatás indítása</translation>
    </message>
    <message>
        <source>Stop service</source>
        <translation type="unfinished">Szolgáltatás leállítása</translation>
    </message>
    <message>
        <source>State:</source>
        <translation type="unfinished">Státusz:</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation type="unfinished">Leállítva</translation>
    </message>
    <message>
        <source>Logging</source>
        <translation type="unfinished">Bejelentkezés</translation>
    </message>
    <message>
        <source>Log file directory</source>
        <translation type="unfinished">Naplófájlok helye</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Log level</source>
        <translation type="unfinished">Naplózási szint</translation>
    </message>
    <message>
        <source>Nothing</source>
        <translation type="unfinished">Semmi</translation>
    </message>
    <message>
        <source>Only critical messages</source>
        <translation type="unfinished">Csak a kritikus üzenetek</translation>
    </message>
    <message>
        <source>Errors and critical messages</source>
        <translation type="unfinished">Hiba és kritikus üzenetek</translation>
    </message>
    <message>
        <source>Warnings and errors</source>
        <translation type="unfinished">Figyelmeztető és kritikus üzenetek</translation>
    </message>
    <message>
        <source>Information, warnings and errors</source>
        <translation type="unfinished">Tájékoztató, figyelmeztető és hiba üzenetek</translation>
    </message>
    <message>
        <source>Debug messages and everything else</source>
        <translation type="unfinished">Az összes hiba üzenet</translation>
    </message>
    <message>
        <source>Limit log file size</source>
        <translation type="unfinished">Naplófájl maximális mérete</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>Clear all log files</source>
        <translation type="unfinished">Naplófájlok ürítése</translation>
    </message>
    <message>
        <source>Desktop capturing</source>
        <translation type="unfinished">Az asztal rögzítése</translation>
    </message>
    <message>
        <source>Enable capturing of layered (semi-transparent) windows</source>
        <translatorcomment>A réteg rögzítésének engedélyezése az ablakban (félig átlátszó)</translatorcomment>
        <translation type="unfinished">Átfedő ablakok rögzítése (félig átlátszó)</translation>
    </message>
    <message>
        <source>Low accuracy (turbo mode)</source>
        <translation type="unfinished">Alacsony felbontás (turbó mód)</translation>
    </message>
    <message>
        <source>Demo server</source>
        <translation type="unfinished">Bemutató szerver</translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished">Hálózat</translation>
    </message>
    <message>
        <source>Core server port</source>
        <translation type="unfinished">Elsődleges szerver port</translation>
    </message>
    <message>
        <source>Demo server port</source>
        <translation type="unfinished">Bemutató szerver port</translation>
    </message>
    <message>
        <source>Enable firewall exception</source>
        <translation type="unfinished">Hozzáadás a tűzfal kivételekhez</translation>
    </message>
    <message>
        <source>Configuration files</source>
        <translation type="unfinished">Konfigurációs fájlok</translation>
    </message>
    <message>
        <source>Global configuration</source>
        <translation type="unfinished">Globális beállítások</translation>
    </message>
    <message>
        <source>Personal configuration</source>
        <translation type="unfinished">Személyes beállítások</translation>
    </message>
    <message>
        <source>Data directories</source>
        <translation type="unfinished">Mentett képernyőképek könyvtára</translation>
    </message>
    <message>
        <source>Snapshots</source>
        <translation type="unfinished">Képernyóképek</translation>
    </message>
    <message>
        <source>Authentication methods</source>
        <translation type="unfinished">Hitelesítési eljárás</translation>
    </message>
    <message>
        <source>Access key management</source>
        <translation type="unfinished">Hozzáférési kulcs kezelő</translation>
    </message>
    <message>
        <source>Logon settings</source>
        <translation type="unfinished">Bejelentkezési beállítások</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Fájl</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Segítség</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished">&amp;Kilépés</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation type="unfinished">Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Save settings into file</source>
        <translation type="unfinished">Beállítások &amp;mentése fájlba</translation>
    </message>
    <message>
        <source>Save settings into file</source>
        <translation type="unfinished">Beállítások mentése fájlba</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished">Ctrl+S</translation>
    </message>
    <message>
        <source>L&amp;oad settings from file</source>
        <translatorcomment>Beállítások be&amp;töltése fájlból</translatorcomment>
        <translation type="unfinished">Beállítások be&amp;töltése fájlból</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation type="unfinished">Ctrl+O</translation>
    </message>
    <message>
        <source>About iTALC</source>
        <translation type="unfinished">Az iTALC névjegye</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation type="unfinished">Qt-ról</translation>
    </message>
    <message>
        <source>MainWindow</source>
        <translation type="unfinished">Főablak</translation>
    </message>
    <message>
        <source>toolBar</source>
        <translation type="unfinished">toolBar</translation>
    </message>
    <message>
        <source>iTALC Management Console %1</source>
        <translation type="unfinished">iTALC Management Konzol %1</translation>
    </message>
    <message>
        <source>Running</source>
        <translation type="unfinished">Futtatás</translation>
    </message>
    <message>
        <source>Load settings from file</source>
        <translation type="unfinished">Beállítások betöltése fájlból</translation>
    </message>
    <message>
        <source>XML files (*.xml)</source>
        <translation type="unfinished">XML-fájlok (*.xml)</translation>
    </message>
    <message>
        <source>Save settings to file</source>
        <translation type="unfinished">Beállítások mentése fájlba</translation>
    </message>
    <message>
        <source>Unsaved settings</source>
        <translation type="unfinished">Nem mentett beállítások</translation>
    </message>
    <message>
        <source>There are unsaved settings. Quit anyway?</source>
        <translation type="unfinished">A beállítások még nincsenek mentve. Biztosan kilép?</translation>
    </message>
    <message>
        <source>Configuration not writable</source>
        <translation type="unfinished">Nem írhatóak ki a beállítások</translation>
    </message>
    <message>
        <source>The local configuration backend reported that the configuration is not writable! Please run the iTALC Management Console with higher privileges.</source>
        <translation type="unfinished">A konfigurációs kezelő visszajelzése alapján nem írható a konfiguráció. Kérlek indítsd el adminisztrátorként az iTALC Management Konzolt.</translation>
    </message>
    <message>
        <source>All settings were applied successfully.</source>
        <translation type="unfinished">Az összes beállítást sikeresen végrehajtottuk.</translation>
    </message>
    <message>
        <source>An error occured while applying settings!</source>
        <translation type="unfinished">Hiba lépett fel a beállítások érvényre juttatása közben!</translation>
    </message>
    <message>
        <source>iTALC</source>
        <translation>iTALC</translation>
    </message>
    <message>
        <source>No write access</source>
        <translation type="unfinished">Nincsen írási engedélye</translation>
    </message>
    <message>
        <source>Could not read/write or create directory %1! For running iTALC, make sure you&apos;re permitted to create or write this directory.</source>
        <translation type="unfinished">Nem olvasható/írható vagy hozható létre a %1 könyvtár! Győződjön meg róla, hogy engedélyezett-e az iTALC számára létrehozni vagy írni ebben a  könyvtárba.</translation>
    </message>
    <message>
        <source>Classroom</source>
        <translation type="unfinished">Osztályterem</translation>
    </message>
    <message>
        <source>Switch classroom</source>
        <translation type="unfinished">Osztályterem választás</translation>
    </message>
    <message>
        <source>Click this button to open a menu where you can choose the active classroom.</source>
        <translation type="unfinished">A gombra kattintva kiválasztható, hogy melyik legyen az aktív osztályterem.</translation>
    </message>
    <message>
        <source>Click on this button, to switch between classrooms.</source>
        <translation type="unfinished">Az osztálytermek között váltáshoz kattintson a gombra.</translation>
    </message>
    <message>
        <source>Overview mode</source>
        <translation type="unfinished">Áttekintési mód</translation>
    </message>
    <message>
        <source>Overview</source>
        <translation type="unfinished">Áttekintés</translation>
    </message>
    <message>
        <source>This is the default mode in iTALC and allows you to have an overview over all visible computers. Also click on this button for unlocking locked workstations or for leaving demo-mode.</source>
        <translatorcomment>Ezzel az alapbeállítással megtekintheti az elérhető gépek listáját az iTALC-ban. A gombra kattintva feloldhatja a munkaállomások blokkolását vagy kiléphet az oktatói bemutató üzemmódból.</translatorcomment>
        <translation type="unfinished">A menü segítségével megtekintheti az elérhető gépeket. A gombra kattintva feloldhatja a munkaállomások blokkolását vagy kiléphet az oktatói bemutató üzemmódból.</translation>
    </message>
    <message>
        <source>Fullscreen demo</source>
        <translation type="unfinished">Oktatói bemutató a teljes képernyőn</translation>
    </message>
    <message>
        <source>Fullscreen Demo</source>
        <translation type="unfinished">Bemutató</translation>
    </message>
    <message>
        <source>Stop Demo</source>
        <translation type="unfinished">Bemutató vége</translation>
    </message>
    <message>
        <source>In this mode your screen is being displayed on all shown computers. Furthermore the users aren&apos;t able to do something else as all input devices are locked in this mode.</source>
        <translation type="unfinished">Ebben az üzemmódban az oktató megoszthatja a képernyőjének a tartalmát. A megosztott képernyő teljes méretben fog megjelenni a tanulók számítógépein. A bemutató közben a tanulók nem foglalkozhatnak mással, mert a beviteli eszközök (egér, billentyűzet) blokkolásra kerülnek.</translation>
    </message>
    <message>
        <source>Window demo</source>
        <translation type="unfinished">Oktatói bemutató ablak méretben</translation>
    </message>
    <message>
        <source>Window Demo</source>
        <translation type="unfinished">Bemutató ablak</translation>
    </message>
    <message>
        <source>In this mode your screen being displayed in a window on all shown computers. The users are able to switch to other windows and thus can continue to work.</source>
        <translation type="unfinished">Ebben az üzemmódban az oktató megoszthatja a képernyőjének a tartalmát. A megosztott képernyő ablak méretben fog megjelenni a tanulók számítógépein.
A bemutató közben a felhasználók mással is foglalkozhatnak.</translation>
    </message>
    <message>
        <source>Lock/unlock desktops</source>
        <translation type="unfinished">Képernyő Blokkolása/feloldása</translation>
    </message>
    <message>
        <source>Lock all</source>
        <translation type="unfinished">Blokkolás</translation>
    </message>
    <message>
        <source>Unlock all</source>
        <translation type="unfinished">Feloldás</translation>
    </message>
    <message>
        <source>To have all user&apos;s full attention you can lock their desktops using this button. In this mode all input devices are locked and the screen is black.</source>
        <translation type="unfinished">Ezzel a gombbal az összes diák gépét blokkolhatja. Ebben az üzemmóddal az összes bemeneti eszközt blokkolja és a képernyők elsötétülnek.</translation>
    </message>
    <message>
        <source>Send text message</source>
        <translation type="unfinished">Üzenet küldése</translation>
    </message>
    <message>
        <source>Text message</source>
        <translation type="unfinished">Szöveges üzenet</translation>
    </message>
    <message>
        <source>Use this button to send a text message to all users e.g. to tell them new tasks etc.</source>
        <translation type="unfinished">A gomb segítségével üzenet küldhet minden felhasználónak. (például: &quot;Kezdhetitek az új feladatot megoldani&quot;, stb..).</translation>
    </message>
    <message>
        <source>Power on computers</source>
        <translation type="unfinished">Számítógépek bekapcsolása</translation>
    </message>
    <message>
        <source>Power on</source>
        <translation type="unfinished">Bekapcsolás</translation>
    </message>
    <message>
        <source>Click this button to power on all visible computers. This way you do not have to turn on each computer by hand.</source>
        <translation type="unfinished">A számítógépek bekapcsolásához kattintsunk a gombra. Így nem kell minden gépet egyesével bekapcsolnunk. (A hardvernek is támogatnia kell a &quot;Wake-on-Lan funkciót&quot;)</translation>
    </message>
    <message>
        <source>Power down computers</source>
        <translation type="unfinished">Számítógépek kikapcsolása</translation>
    </message>
    <message>
        <source>Power down</source>
        <translation type="unfinished">Kikapcsolás</translation>
    </message>
    <message>
        <source>To power down all shown computers (e.g. after the lesson has finished) you can click this button.</source>
        <translation type="unfinished">Az összes elérhető számítógép kikapcsolásához kattintson a gombra. (az óra végeztével kikapcsolhatja az összes számítógépet).</translation>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished">Támogatás</translation>
    </message>
    <message>
        <source>Direct support</source>
        <translation type="unfinished">Közvetlen támogatás</translation>
    </message>
    <message>
        <source>If you need to support someone at a certain computer you can click this button and enter the according hostname or IP afterwards.</source>
        <translation type="unfinished">Ha egy diáknak szüksége van támogatásra, a gombra kattintva a gép nevét vagy az IP címét beírva csatlakozhat és segítséget nyújthat.</translation>
    </message>
    <message>
        <source>Adjust/align</source>
        <translation type="unfinished">Elrendezés</translation>
    </message>
    <message>
        <source>Adjust windows and their size</source>
        <translation type="unfinished">Ablak méretének beállítása</translation>
    </message>
    <message>
        <source>When clicking this button the biggest possible size for the client-windows is adjusted. Furthermore all windows are aligned.</source>
        <translation type="unfinished">A gombra kattintva a lehető legnagyobb méretben tekinthetjük meg a felhasználók asztalát. Továbbá az összes ablakot ehhez igazíthatjuk.</translation>
    </message>
    <message>
        <source>Auto view</source>
        <translation type="unfinished">Automatikus nézet</translation>
    </message>
    <message>
        <source>Auto re-arrange windows and their size</source>
        <translation type="unfinished">Az ablakok automatikus újrarendezése és átméretezése</translation>
    </message>
    <message>
        <source>When clicking this button all visible windows are re-arranged and adjusted.</source>
        <translation type="unfinished">Ide kattintva az elérhető ablakok sorrendét módosíthatjuk vagy rendezhetjük át.</translation>
    </message>
    <message>
        <source>iTALC Master Control</source>
        <translation type="unfinished">iTALC Tanár kontroll</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation type="unfinished">Távoligép kezelés</translation>
    </message>
    <message>
        <source>Could not modify the autostart property for the iTALC Service.</source>
        <translation type="unfinished">Az iTALC nem tudta modosítani a Windows &quot;autostart&quot; beállításait.</translation>
    </message>
    <message>
        <source>Could not modify the service arguments for the iTALC Service.</source>
        <translation type="unfinished">Az iTALC nem tudta modosítani a Windows szolgáltatás argumentumait.</translation>
    </message>
    <message>
        <source>Could not change the firewall configuration for the iTALC Service.</source>
        <translation type="unfinished">Az iTALC nem tudta megváltoztatni a Windows tűzfal konfigurációját.</translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation type="unfinished">Hibakeresés</translation>
    </message>
    <message>
        <source>Enable desktop switching for screen lock (experimental)</source>
        <translation type="unfinished">Képernyő blokkolása asztalváltáskor (kísérleti)</translation>
    </message>
    <message>
        <source>Log to standard error output</source>
        <translatorcomment>Hibanaplózás az elsődleges kimenetre /Standard error output-ra történő naplózás</translatorcomment>
        <translation type="unfinished">Naplózás az elsődleges hiba kimenetre</translation>
    </message>
    <message>
        <source>Log to Windows event log</source>
        <translatorcomment>Naplózás a rendszer esemény naplójába / A (Windows )rendszer eseménynapló használata</translatorcomment>
        <translation type="unfinished">Naplózás a Windows eseménynaplóba</translation>
    </message>
    <message>
        <source>Backend</source>
        <translation type="unfinished">Backend</translation>
    </message>
    <message>
        <source>VNC reflector</source>
        <translation type="unfinished">VNC reflektor</translation>
    </message>
    <message>
        <source>iTALC 1 demo server</source>
        <translation type="unfinished">iTALC 1 Bemutató szerver</translation>
    </message>
    <message>
        <source>Multithreading (can be enabled when using the VNC reflector backend)</source>
        <translation type="unfinished">Többszálú futtatás (ajánlott a VNC reflektor használatánál)</translation>
    </message>
    <message>
        <source>Enable HTTP server which provides a JavaViewer applet</source>
        <translation type="unfinished">A HTTP szerver futásának engedélyezése a JavaViewer alkalmazáshoz</translation>
    </message>
    <message>
        <source>HTTP server port</source>
        <translation type="unfinished">HTTP-Szerver port</translation>
    </message>
    <message>
        <source>Allow connections from localhost only</source>
        <translation type="unfinished">Kapcsolatok engedélyezése kizárólag a helyi gépről</translation>
    </message>
    <message>
        <source>Key file authentication</source>
        <translation type="unfinished">Kulcsos azonosítás</translation>
    </message>
    <message>
        <source>ACL-based logon authentication</source>
        <translation type="unfinished">ACL-alapú bejelentkezés</translation>
    </message>
    <message>
        <source>Public key file base directory</source>
        <translation type="unfinished">Publikus kulcs könyvtára</translation>
    </message>
    <message>
        <source>Private key file base directory</source>
        <translation type="unfinished">Privát kulcs könyvtára</translation>
    </message>
    <message>
        <source>Launch key file assistant</source>
        <translation type="unfinished">Hozzáférési kulcs Varázsló</translation>
    </message>
    <message>
        <source>Manage permissions</source>
        <translation type="unfinished">Engedélyek kezelése</translation>
    </message>
    <message>
        <source>Test</source>
        <translation type="unfinished">Teszt</translation>
    </message>
    <message>
        <source>Access confirmation</source>
        <translation type="unfinished">Hozzáférés megerősítése</translation>
    </message>
    <message>
        <source>You can configure iTALC to ask the user for permission to access the desktop when using certain authentication methods.</source>
        <translatorcomment>Beállíthatja az iTalcot, hogy felhasználói engedélyt kérjen a számítógéphez való hozzáféréshez, amikor bizonyos hitelesítési módszereket alkalmaz.</translatorcomment>
        <translation type="unfinished">A számítógépek hozzáférésének hitelesítés-módszereinek beállításai.</translation>
    </message>
    <message>
        <source>Logon authentication</source>
        <translation type="unfinished">Bejelentkezés hitelesítéssel</translation>
    </message>
    <message>
        <source>Allow same user to access desktop without confirmation</source>
        <translation type="unfinished">Megerősítés nélkül engedélyezzük a hozzáférést ugyan annak a felhasználónak</translation>
    </message>
    <message>
        <source>Debugging iTALC</source>
        <translation type="unfinished">Hibakeresés az iTALC-ban</translation>
    </message>
    <message>
        <source>When encountering bugs or other misbehaviour in iTALC it is important to inform the developers about them, so that the bugs can be fixed in future releases. This page allows you to submit a helpful bug report easily.

If the bug is not reproducible, skip step 1) - 3).</source>
        <translation type="unfinished">Amennyiben rendellenes működést tapasztal az iTALC használata közben, kérem hogy mielőbb tájékoztassa a fejlesztőket a problémáról. Az útmutató segítségével könnyedén elkészítheti a hibajelentést. A visszajelzések segítségével elkerülhetőek lesznek a működésebeli problémák, és hozzájárulhat a program tökéletesítéséhez is.

Ha a hiba nem reprodukálható, akkor hagyja ki a 1) -3) lépéseket.</translation>
    </message>
    <message>
        <source>1)</source>
        <translation>1)</translation>
    </message>
    <message>
        <source>Clear the logfiles in the &quot;General&quot; section.</source>
        <translation type="unfinished">Törölje a naplófájlokat. Az &quot;Általános&quot; menüpont alatt találja a &quot;Naplófájlok ürítése&quot; gombot.</translation>
    </message>
    <message>
        <source>2)</source>
        <translation>2)</translation>
    </message>
    <message>
        <source>In the &quot;General&quot; section set the log level to &quot;Debug messages and everything else&quot;.</source>
        <translation type="unfinished">Az &quot;Általános&quot; menüpontban válassza ki a naplózási szintnek: &quot;Az összes hiba üzenet&quot;.</translation>
    </message>
    <message>
        <source>3)</source>
        <translation>3)</translation>
    </message>
    <message>
        <source>Repeat the actions leading to the bug or misbehaviour.</source>
        <translation type="unfinished">Ismételje meg azokat a lépéseket, amik a hibához vagy a rendellenes működéshez vezettek.</translation>
    </message>
    <message>
        <source>4)</source>
        <translation>4)</translation>
    </message>
    <message>
        <source>Click the following button and save the file to a known location.</source>
        <translation type="unfinished">A gombra kattintva készíthet-, és mentheti el a hibajelentést.</translation>
    </message>
    <message>
        <source>Generate bug report archive</source>
        <translation type="unfinished">Hibajelentés készítése</translation>
    </message>
    <message>
        <source>5)</source>
        <translation>5)</translation>
    </message>
    <message>
        <source>Go to the &lt;a href=&quot;http://sourceforge.net/tracker/?group_id=132465&amp;amp;atid=724375&quot;&gt;iTALC bug tracker&lt;/a&gt;, open a new bug, describe what you did in step 3) and attach the file you saved in step 4).&lt;/p&gt;
&lt;br/&gt;
&lt;br/&gt;
Note: if the bug involves both a master and client computer, attach bug report archives for both computers.</source>
        <translation type="unfinished">Kérem látogasson el &lt;a href=&quot;http://sourceforge.net/tracker/?group_id=132465&amp;amp;atid=724375&quot;&gt;az iTALC hibajelentő weboldalára&lt;/a&gt;, majd nyisson egy hibajegyet. A 3) lépésben leírtakat hajtsa végre, és a 4) lépésnek megfelelően mentse el az elkészült hibajelentést.&lt;/p&gt;
&lt;br/&gt;
&lt;br/&gt;
Megjegyzés: amennyiben a hiba mind  a master (tanári) és a kliens (diák) számítógépeken is előfordult, akkor csatolja mind a két számítógéphez tartoró hibajelentését.</translation>
    </message>
    <message>
        <source>Restart iTALC Service</source>
        <translation type="unfinished">iTALC szolgáltatás újraindítása</translation>
    </message>
    <message>
        <source>All settings were saved successfully. In order to take effect the iTALC service needs to be restarted. Restart it now?</source>
        <translation type="unfinished">Az összes beállítást sikeren elmentettük. Annak érdekében, hogy a beállítások érvényre jussanak, újra kell indítani az iTALC szolgáltatást. Újraindítja ?</translation>
    </message>
    <message>
        <source>Starting iTALC service</source>
        <translation type="unfinished">iTALC szolgáltatás indítása</translation>
    </message>
    <message>
        <source>Stopping iTALC service</source>
        <translation type="unfinished">iTALC szolgáltatás leállítása</translation>
    </message>
    <message>
        <source>The iTALC service needs to be stopped temporarily in order to remove the log files. Continue?</source>
        <translation type="unfinished">Az iTALC szolgáltatást arra az átmeneti időre le kell állítani, amíg a naplófájlt eltávolítjuk. Folytassuk?</translation>
    </message>
    <message>
        <source>Log files cleared</source>
        <translation type="unfinished">A naplófájl törölve</translation>
    </message>
    <message>
        <source>All log files were cleared successfully.</source>
        <translation type="unfinished">Az naplófájlok ürítése sikeresen megtörtént.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Hiba</translation>
    </message>
    <message>
        <source>Could not remove all log files.</source>
        <translation type="unfinished">Nem törölhető az összes naplófájl.</translation>
    </message>
    <message>
        <source>Logon authentication test</source>
        <translation type="unfinished">Bejelentkezési hitelesítés vizsgálata</translation>
    </message>
    <message>
        <source>Authentication with provided credentials was successful.</source>
        <translation type="unfinished">A hozzáférési hitelesítés sikeresen megtörtént.</translation>
    </message>
    <message>
        <source>Authentication with provided credentials failed!</source>
        <translation type="unfinished">A hozzáférési hitelesítés sikertelenül fejeződött be!</translation>
    </message>
    <message>
        <source>Save bug report archive</source>
        <translation type="unfinished">Bug jelentés elmentése</translation>
    </message>
    <message>
        <source>iTALC bug report archive (*.ibra.xml)</source>
        <translation type="unfinished">iTALC bug report archiválás (*.ibra.xml)</translation>
    </message>
    <message>
        <source>iTALC bug report archive saved</source>
        <translation type="unfinished">Az iTALC &quot;bug&quot; hibajelentések mentése megtörtént</translation>
    </message>
    <message>
        <source>An iTALC bug report archive has been saved to %1. It includes iTALC log files and information about your operating system. You can attach it to a bug report.</source>
        <translation type="unfinished">Az iTALC hiba jelentése mentésre került a %1 -ba. A jelentés tartalmazza az iTALC naplófájlt és egyéb információkat az operációs rendszerről. Ezt csatolhatja a hibajelentéshez.</translation>
    </message>
    <message>
        <source>Could not contact iTALC service</source>
        <translation type="unfinished">Az iTALC szolgáltatás kapcsolata megszakadt</translation>
    </message>
    <message>
        <source>Could not contact the local iTALC service. It is likely that you entered wrong credentials or key files are not set up properly. Try again or contact your administrator for solving this problem using the iTALC Management Console.</source>
        <translation type="unfinished">Nem létesíthető kapcsolat a helyi iTALC szolgáltatással. Feltehetően rossz hitelesítési adatokkal vagy kulcs azonosítással próbálkozik. Próbálja meg ismét vagy lépjen kapcsolatba a rendszer adminisztrátorral a probléma megoldása érdekében, ehhez használja az iTALC Management Konzolt.</translation>
    </message>
    <message>
        <source>Authentication impossible</source>
        <translation type="unfinished">Lehetetlen a hitelesítés</translation>
    </message>
    <message>
        <source>No authentication key files were found or your current ones are outdated. Please create new key files using the iTALC Management Console. Alternatively set up logon authentication using the iTALC Management Console. Otherwise you won&apos;t be able to access computers using iTALC.</source>
        <translation type="unfinished">Nem találhatóak vagy már lejártak a hitelességet érvényesítő kulcsok. Kérem hozzon létre új hitelesítő kulcsokat az iTALC Management Konzol segítségével. Az iTALC Management Konzol segítségével választhat más azonosítási eljárások közül. Nem megfelelő azonosítási eljárási esetében az iTALC nem fog megfelelően működni.</translation>
    </message>
    <message>
        <source>Poll full screen (leave this enabled per default)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageBoxSlave</name>
    <message>
        <source>Message from teacher</source>
        <translation type="unfinished">Üzenet a tanártól</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600; font-style:italic;&quot;&gt;Welcome to iTALC!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600; font-style:italic;&quot;&gt;Üdvözlöm az iTALC-ban!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Here you see the working-bar which contains several buttons. Each button is connected to a workspace. Just take a look at the available workspaces by clicking on the corresponding button.</source>
        <translatorcomment>Ezen a munkaterületen található vezérlő gombok segítségével végezhetjük el az alapvető adminisztrációs műveleteket. Segítségével tudunk csatlakozni különböző munkaasztalokhoz. Az elérhető munkaterület(ek) megjelölése a megfelelő gombra kattintva választható ki.
vagy Az elérhető munkaterület(ek) / munkaasztal(ok) kiválasztásához kattintson a megfelelő gombra.</translatorcomment>
        <translation type="unfinished">A munkafelületen található vezérlő gombok segítségével végezhetjük el az alapvető adminisztrációs műveleteket. Ennek segítségével tudunk csatlakozni más munkaállomásokhoz. Az elérhető munkaterület(ek)et / munkaasztalok(at) a megfelelő gombra kattintva választhatjuk ki.</translation>
    </message>
    <message>
        <source>Using the classroom-manager you can manage your classrooms and computers. You can also see which users are logged in.</source>
        <translation type="unfinished">Csak a felügyelő személy kezelheti az osztálytermeket és a számítógépeket. Ezenkívül a bejelentkezett felhasználókat tudja megtekinteni.</translation>
    </message>
    <message>
        <source>The snapshot-workspace is a very useful tool. It let&apos;s you manage the snapshots you made.</source>
        <translatorcomment>Nagyon hasznos a képernyőkép készítő eszköz. /A képernyőkép készítő eszköz nagyon hasznos</translatorcomment>
        <translation type="unfinished">Nagyon hasznos a képernyőkép készítő eszköz. Segítségével könnyedén kezelhetjük a különböző munkaasztalokról elkészült képeket.</translation>
    </message>
    <message>
        <source>Of course you can configure iTALC. This is usually done using the configuration-workspace.</source>
        <translatorcomment>A testreszabáshoz a konfigurációs használjuk.</translatorcomment>
        <translation type="unfinished">Természetesen az iTALC is testreszabható. A munkaasztalok beállítását a konfigurációs menüből érhetjük el.</translation>
    </message>
    <message>
        <source>About iTALC</source>
        <translation type="unfinished">Az iTALC névjegye</translation>
    </message>
</context>
<context>
    <name>OverviewWidget</name>
    <message>
        <source>Overview</source>
        <translation type="unfinished">Áttekintés</translation>
    </message>
    <message>
        <source>Some basic information on iTALC and how to use it.</source>
        <translation type="unfinished">Néhány alapvető információt megtalál az iTALC-ról és arról, hogy, hogyan használjuk.</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Please enter your username and password in order to access iTALC clients.</source>
        <translation type="unfinished">Kérem írja be a felhasználó nevét és a jelszavát a iTALC kliens indításához.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished">Felhasználó</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished">Jelszó</translation>
    </message>
    <message>
        <source>iTALC Logon</source>
        <translation type="unfinished">iTALC bejelentkezés</translation>
    </message>
    <message>
        <source>Manage</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Unable to register service &apos;%1&apos;.</source>
        <translation type="unfinished">Nem sikerült regisztrálni a %1 szolgáltatást.</translation>
    </message>
    <message>
        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not registered.</source>
        <translation type="unfinished">A Service Control Manager nem tudott kapcsolódni (rendelkezik Ön a megfelelő jogosultságokkal?!) - a &apos;%1&apos; szolgáltatás nem volt regisztrálva.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; is already registered.</source>
        <translation type="unfinished">A %1 szolgáltatás már regisztrálva van.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be registered.</source>
        <translation type="unfinished">Nem regisztrálódott a %1 szolgáltatás.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; was successfully registered.</source>
        <translation type="unfinished">A %1 szolgáltatás sikeresen regisztrálódott.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be stopped.</source>
        <translation type="unfinished">Nem sikerült leállítani a %1 szolgáltatást.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; has been unregistered.</source>
        <translation type="unfinished">A %1 szolgáltatás már nincsen regisztrálva.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; isn&apos;t registered and therefore can&apos;t be unregistered.</source>
        <translation type="unfinished">Ez a %1 szolgáltatás nem regisztrált ezért nem lehet törölni.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be unregistered.</source>
        <translation type="unfinished">A %1 szolgáltatást nem lehetett regisztrálni.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be found.</source>
        <translation type="unfinished">Nem található a &apos;%1&apos; szolgáltatás.</translation>
    </message>
    <message>
        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not unregistered.</source>
        <translation type="unfinished">A Service Control Manager nem tudott kapcsolódni (rendelkezik Ön a megfelelő jogosultságokkal?!) - a &apos;%1&apos; szolgáltatás még nem volt regisztrálva.</translation>
    </message>
    <message>
        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not stopped.</source>
        <translation type="unfinished">A Service Control Manager nem tudott kapcsolódni (rendelkezik Ön a megfelelő jogosultságokkal?!) - a &apos;%1&apos; szolgáltatás nem állt meg.</translation>
    </message>
    <message>
        <source>iTALC Client %1 on %2:%3</source>
        <translation type="unfinished">Az iTALC kliens %1 elérhető %2:%3</translation>
    </message>
</context>
<context>
    <name>RemoteControlWidget</name>
    <message>
        <source>View live (%1 @ %2)</source>
        <translation type="unfinished">Elöl nézet (%1 @ %2)</translation>
    </message>
    <message>
        <source>Remote control (%1 @ %2)</source>
        <translation type="unfinished">Távoli hozzáférés (%1 @ %2)</translation>
    </message>
    <message>
        <source>unknown user</source>
        <translation type="unfinished">ismeretlen felhasználó</translation>
    </message>
</context>
<context>
    <name>RemoteControlWidgetToolBar</name>
    <message>
        <source>View only</source>
        <translation type="unfinished">Csak nézet</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation type="unfinished">Távoli hozzáférés</translation>
    </message>
    <message>
        <source>Lock student</source>
        <translation type="unfinished">Diák gép blokkolása</translation>
    </message>
    <message>
        <source>Unlock student</source>
        <translation type="unfinished">Diák gép feloldása</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation type="unfinished">Képernyőképek</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished">Teljes képernyő</translation>
    </message>
    <message>
        <source>Window</source>
        <translation type="unfinished">Ablak</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished">Kilépés</translation>
    </message>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished">A kapcsolódás folyamatban %1</translation>
    </message>
    <message>
        <source>Connected.</source>
        <translation type="unfinished">Kapcsolódva.</translation>
    </message>
</context>
<context>
    <name>RemoteLogonDialog</name>
    <message>
        <source>Remote logon</source>
        <translation type="unfinished">Távoli bejelentkezés</translation>
    </message>
    <message>
        <source>Use the fields below to enter the username, password and optional the domain name. These information will be used to logon the computer(s).</source>
        <translation type="unfinished">Töltse ki az alábbi mezőket, adja meg a felhasználói nevét, jelszavát vagy domain név alapú azonosítást is használhatja. Ezeket az információkat fogják használni a számítógép bejelentkezéséhez.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished">Felhasználó</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished">Jelszó</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation type="unfinished">Domain</translation>
    </message>
</context>
<context>
    <name>RunCommandsDialog</name>
    <message>
        <source>Run commands</source>
        <translation type="unfinished">Parancs futtatása</translation>
    </message>
    <message>
        <source>Please enter the commands to run on the selected client(s). You can separate multiple commands by line.</source>
        <translation type="unfinished">Kérem adja meg a parancsokat amiket futtatni szeretne a kijelölt kliens gépeken. Több parancs futtatásához használjon új sorokat.</translation>
    </message>
</context>
<context>
    <name>Snapshot</name>
    <message>
        <source>unknown</source>
        <translation type="unfinished">ismeretlen</translation>
    </message>
    <message>
        <source>Could not take a snapshot as directory %1 doesn&apos;t exist and couldn&apos;t be created.</source>
        <translation type="unfinished">Nem lehet képernyőképeket készíteni, ,mert a %1 könyvtár még nem létezik, és nem is hozható létre.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation type="unfinished">Képernyőkép</translation>
    </message>
</context>
<context>
    <name>SnapshotList</name>
    <message>
        <source>Snapshots</source>
        <translation type="unfinished">Képernyőképek</translation>
    </message>
    <message>
        <source>Simply manage the snapshots you made using this workspace.</source>
        <translation type="unfinished">A munkaterület segítségével egyszerűen kezelheti a képernyőképeket.</translation>
    </message>
</context>
<context>
    <name>Snapshots</name>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;All snapshots you made are listed here. You can make snapshots by selecting the according entry in the context-menu of a client-window. These snapshosts can be managed using the buttons below.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translatorcomment>You can make snapshots by selecting the according entry in the context-menu of a client-window. =? Csinálhat pillanatképet a felhasználói felület (képernyő) megfelelő szövegének a kiválasztásával.</translatorcomment>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Kilistázhatja az elkészült képernyőképeket. You can make snapshots by selecting the according entry in the context-menu of a client-window. Az alábbi gomb megnyomásával kezelheti  az elkészült képernyőképeket.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>User:</source>
        <translation type="unfinished">Felhasználó:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation type="unfinished">Gépnév:</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation type="unfinished">Dátum:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation type="unfinished">Idő:</translation>
    </message>
    <message>
        <source>Show</source>
        <translation type="unfinished">Nézet</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Törlés</translation>
    </message>
</context>
<context>
    <name>SupportDialog</name>
    <message>
        <source>Support</source>
        <translation type="unfinished">Támogatás</translation>
    </message>
    <message>
        <source>Please enter the IP address or the name of the host to which you want to connect.</source>
        <translation type="unfinished">Kérem írja be annak a gépnek az IP címét vagy a nevét amihez csatlakozni szeretne.</translation>
    </message>
</context>
<context>
    <name>TextMessageDialog</name>
    <message>
        <source>Send text message</source>
        <translation>Szöveges üzenet küldése</translation>
    </message>
    <message>
        <source>Use the field below to type your message which will be sent to all selected users.</source>
        <translation type="unfinished">Ide írhatja be azt az üzenetet, amit elszeretne küldeni a kijelölt tanulóknak.</translation>
    </message>
</context>
<context>
    <name>VncView</name>
    <message>
        <source>Establishing connection to %1 ...</source>
        <translation>Kapcsolat létrehozása a %1 ...</translation>
    </message>
</context>
<context>
    <name>clientMenu</name>
    <message>
        <source>Overview</source>
        <translation type="unfinished">Áttekintés</translation>
    </message>
    <message>
        <source>Fullscreen demo</source>
        <translation type="unfinished">Bemutató a teljes képernyőn</translation>
    </message>
    <message>
        <source>Window demo</source>
        <translation type="unfinished">Bemutató ablakban</translation>
    </message>
    <message>
        <source>Locked display</source>
        <translation>Képernyő blokkolása</translation>
    </message>
    <message>
        <source>View live</source>
        <translation type="unfinished">Távoli gép követése (teljes képernyőn)</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation type="unfinished">Távoli számítógép átvétele</translation>
    </message>
    <message>
        <source>Let student show demo</source>
        <translation type="unfinished">Oktatói bemutató indítása a tanulói gépen</translation>
    </message>
    <message>
        <source>Send text message</source>
        <translation>Szöveges üzenet küldése</translation>
    </message>
    <message>
        <source>Logout user</source>
        <translation>Kijelentkezés</translation>
    </message>
    <message>
        <source>Take a snapshot</source>
        <translation type="unfinished">Képernyőkép készítése</translation>
    </message>
    <message>
        <source>Power on</source>
        <translation>Bekapcsolás</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Újraindítás</translation>
    </message>
    <message>
        <source>Power down</source>
        <translation>Kikapcsolás</translation>
    </message>
    <message>
        <source>Execute commands</source>
        <translation type="unfinished">Parancs futtatása</translation>
    </message>
</context>
</TS>
